@@ -30,4 +30,4 @@ def select_action(args):
 if __name__ == "__main__":
     # Parsing arguments
     args = parser.parse_args()
-    select_action(args)
+    print(select_action(args))
