@@ -11,6 +11,6 @@ def split_letters(input_text):
 
 
 def read_from_file(file_path):
-    with open(f'collection_framework/{file_path}', "r") as file:
+    with open(f'anton_cli/{file_path}', "r") as file:
         string = file.read().splitlines()
         return [split_letters(el) for el in string]
